@@ -6,7 +6,7 @@ Copyright (c) 2013, Wladston Viana.
 """
 
 __author__ = 'Wladston Viana'
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 __license__ = 'MIT'
 
 # Python.
@@ -19,16 +19,22 @@ from pymongo.son_manipulator import SONManipulator
 
 connection = None
 db = None
+_manipulators = []
 
 # MongoDB will not store dates with milliseconds.
 milli_trim = lambda x: x.replace(microsecond=int((x.microsecond/1000)*1000))
 
 
 def setup(database_name):
-    global db, connection
+    global db, connection, _manipulators
     connection = MongoClient('localhost', 27017, tz_aware=True)
     db = getattr(connection, database_name)
 
+    for x in _manupilators:
+        db.add_son_manipulator(x)
+
+    _manipulators = []
+
     return db
 
 
@@ -125,6 +131,9 @@ class ModelType(type):
         if db:
             db.add_son_manipulator(_ModelManipulator(cls))
 
+        else:
+            _manipulators.append(_ModelManipulator(cls))
+
         return cls
 
 
